@@ -4,6 +4,9 @@ use thiserror::Error;
 #[derive(Error, Debug, Diagnostic)]
 pub(crate) enum MitPrepareCommitMessageError {
     #[error("Expected commit file path")]
-    #[diagnostic()]
+    #[diagnostic(
+        url(docsrs),
+        code(mit_prepare_commit_msg::errors::missing_commit_file_path)
+    )]
     MissingCommitFilePath,
 }
